#! /bin/sh
#
# Copyright (c) 2002 Benjamin Scott <bscott@chiark.greenend.org.uk>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License,
# version 2.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
#
# System startup script for the Logitech Media Server.

# get site config
INSTALL_ROOT=/share/Apps/LogitechMediaServer
PATH=/sbin:/usr/sbin:/bin:/usr/bin:${INSTALL_ROOT}/bin;export PATH
DESC="Logitech Media Server"
NAME=logitechmediaserver

if [ -f "${INSTALL_ROOT}/config/${NAME}.conf" ];then
    . ${INSTALL_ROOT}/config/${NAME}.conf
else
    log_warning_msg "$NAME: No config file found in ${INSTALL_ROOT}/config/"
    exit 1
fi


case "$1" in
    start)
        if [ ! -d ${LOGITECH_MEDIA_SERVER_CACHEDIR} ]; then
            mkdir -p ${LOGITECH_MEDIA_SERVER_CACHEDIR}
            mkdir -p ${LOGITECH_MEDIA_SERVER_PREFSDIR}
        fi
        chmod -R 777 ${LOGITECH_MEDIA_SERVER_HOME} ${LOGITECH_MEDIA_SERVER_PREFSDIR} ${LOGITECH_MEDIA_SERVER_CACHEDIR}
        chmod 777 ${LOGITECH_MEDIA_SERVER_LOG}
        chown ${LOGITECH_MEDIA_SERVER_USER}:${LOGITECH_MEDIA_SERVER_GROUP} ${LOGITECH_MEDIA_SERVER_LOG} ${LOGITECH_MEDIA_SERVER_PREFSDIR} ${LOGITECH_MEDIA_SERVER_CACHEDIR}
        if [ ${LOGITECH_MEDIA_SERVER_START} = "yes" ]; then
		echo -n "Starting $DESC "
		if [ ! -x $LOGITECH_MEDIA_SERVER_BIN ] ; then
		  echo "Failed: $DESC binary ${LOGITECH_MEDIA_SERVER_BIN} is not executable."
		  exit 1
		fi
	#
	# Fire up the server script, redirecting errors to the bit bucket.
	#
		if [ -s ${LOGITECH_MEDIA_SERVER_PIDFILE} ]; then
		    LOGITECH_MEDIA_SERVER_PID=`cat ${LOGITECH_MEDIA_SERVER_PIDFILE} 2>/dev/null`
	    		if [ -d /proc/${LOGITECH_MEDIA_SERVER_PID} ]; then
				echo "already running."
				exit 0;
	    		else
			rm -f ${LOGITECH_MEDIA_SERVER_PIDFILE};
	    		fi
	    	LOGITECH_MEDIA_SERVER_PID=
		fi
		$LOGITECH_MEDIA_SERVER_BIN --daemon --pidfile=${LOGITECH_MEDIA_SERVER_PIDFILE} \
			--httpport=${LOGITECH_MEDIA_SERVER_HTTPPORT} \
			--user=${LOGITECH_MEDIA_SERVER_USER} --group=${LOGITECH_MEDIA_SERVER_GROUP} \
			--logfile=${LOGITECH_MEDIA_SERVER_LOG} \
			--cachedir=${LOGITECH_MEDIA_SERVER_CACHEDIR} \
			--prefsdir=${LOGITECH_MEDIA_SERVER_PREFSDIR} \
			${LOGITECH_MEDIA_SERVER_ARGS} >> ${LOGITECH_MEDIA_SERVER_LOG} 2>&1 
		RETVAL=$?

		LOGITECH_MEDIA_SERVER_PID=`cat ${LOGITECH_MEDIA_SERVER_PIDFILE} 2>/dev/null`
		if [ $RETVAL -eq 0 ] && [ ! -z ${LOGITECH_MEDIA_SERVER_PID} ]; then
		    echo "$DESC daemon started OK. PID is ${LOGITECH_MEDIA_SERVER_PID}."
		    exit 0
		else
		    echo "$DESC failed to run. Return value: $RETVAL."
		    exit 1
		fi
        fi
	;;
    
     stop)

	if test ! -r ${LOGITECH_MEDIA_SERVER_PIDFILE} ; then
	    echo "Can't stop $DESC as it is not running. There is no PID file"
	    exit 1
	fi

	LOGITECH_MEDIA_SERVER_PID=`cat ${LOGITECH_MEDIA_SERVER_PIDFILE} 2>/dev/null`
	if test ! -d /proc/${LOGITECH_MEDIA_SERVER_PID} ; then
	    echo "Can't stop $DESC as it is not running.  There is no process with PID ${LOGITECH_MEDIA_SERVER_PID}."
	    rm -f ${LOGITECH_MEDIA_SERVER_PIDFILE}
	    exit 2
	fi

	echo -n "Shutting down $DESC (please wait) "

	kill ${LOGITECH_MEDIA_SERVER_PID} 2>/dev/null

	count=0
	maxcount=20

	while [ $count -lt $maxcount ]
	do
	 if [  ! -f /proc/${LOGITECH_MEDIA_SERVER_PID}/cmdline ] ;  then
		break;
	   fi
	 /bin/sleep 2
	 count=$((count+1))
	done
	
	if [ ! -f $/proc/${LOGITECH_MEDIA_SERVER_PID}/cmdline ] ; then
	    echo " OK - stop succeeded."
	    rm -f ${LOGITECH_MEDIA_SERVER_PIDFILE} 2>/dev/null
	    exit 0
	else
	    echo " FAILED! Try to kill it. Couldn't kill process $PID"
	    exit 1
	fi
	;;

    status)
	echo -n "Checking for $DESC: "

	if test ! -r ${LOGITECH_MEDIA_SERVER_PIDFILE} ; then
	    echo "Can't stop $DESC as it is not running. There is no PID file"
	    exit 1
	fi

	LOGITECH_MEDIA_SERVER_PID=`cat ${LOGITECH_MEDIA_SERVER_PIDFILE} 2>/dev/null`
	if test -z ${LOGITECH_MEDIA_SERVER_PID} ; then
	    echo "Can't stop $DESC as it is not running. PID file exist but no PID number"
	    exit 0
	fi
	if test -d /proc/${LOGITECH_MEDIA_SERVER_PID} ; then
	    echo " running - process ${LOGITECH_MEDIA_SERVER_PID}"	
	    exit 0
	else
   	    echo " not running - last PID ${LOGITECH_MEDIA_SERVER_PID})"
	    rm -f ${LOGITECH_MEDIA_SERVER_PIDFILE}
	    exit 2
	fi
	;;

    *)
	echo "Usage: $0 {start|stop|status}"
	exit 1
	;;
esac

